const fs = require('fs-extra');
var path = require('path');
const prettify = require('html-prettify');
const { execSync } = require('child_process');
const DIRPATH = `${__dirname}/specs`;

var walk = function (dir, done) {
    var results = [];
    fs.readdir(dir, function (err, list) {
        if (err) return done(err);
        var i = 0;
        (function next() {
            var file = list[i++];
            if (!file) return done(null, results);
            file = path.resolve(dir, file);
            fs.stat(file, function (err, stat) {
                if (stat && stat.isDirectory()) {
                    walk(file, function (err, res) {
                        results = results.concat(res);
                        next();
                    });
                } else {
                    var src = path.relative(process.cwd(), file);
                    var dest = path.dirname(path.relative(process.cwd(), file));
                    var fileName = path.basename(path.relative(process.cwd(), file));
                    fileName = fileName.split('.').slice(0, -1).join('.');
                    dest = dest.replace("specs", "html");
                    console.log(src, dest);
                    execSync(`ag ${src} @asyncapi/html-template -o ${dest} --force-write`);

                    let content = fs.readFileSync(`${dest}/index.html`, 'utf8');
                    content = content.replace(`<script src="js/highlight.min.js" type="application/javascript"></script>`, '');
                    content = content.replace(`js/main.js`, '../../../lib/main.js')
                    content = content.replace('css/main.min.css', '../../../css/async-styles.css');
                    content = content.replace(/hljs/g, 'highlight');
                    content = content.replace(/bg-gray-100/g, 'background-gray-100');
                    content = content.replace(/bg-gray-200/g, 'background-gray-200');
                    content = content.replace(/bg-gray-300/g, 'background-gray-300');
                    content = prettify(content);
                    fs.writeFileSync(`${dest}/index.html`, content);
                    fs.copySync(`${dest}/index.html`, `${dest}/${fileName}.html`);

                    fs.removeSync(`${dest}/index.html`);
                    fs.removeSync(`${dest}/css`);
                    fs.removeSync(`${dest}/js`);

                    results.push(file);
                    next();
                }
            });
        })();
    });
};


walk('specs', function (err, results) {
    if (err) throw err;
});